@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -66,7 +66,10 @@ class GrafeasClientMeta(type):
     _transport_registry["grpc"] = GrafeasGrpcTransport
     _transport_registry["grpc_asyncio"] = GrafeasGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[GrafeasTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[GrafeasTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -162,9 +165,15 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         return self._transport
 
     @staticmethod
-    def note_path(project: str, note: str,) -> str:
+    def note_path(
+        project: str,
+        note: str,
+    ) -> str:
         """Returns a fully-qualified note string."""
-        return "projects/{project}/notes/{note}".format(project=project, note=note,)
+        return "projects/{project}/notes/{note}".format(
+            project=project,
+            note=note,
+        )
 
     @staticmethod
     def parse_note_path(path: str) -> Dict[str, str]:
@@ -173,10 +182,14 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def occurrence_path(project: str, occurrence: str,) -> str:
+    def occurrence_path(
+        project: str,
+        occurrence: str,
+    ) -> str:
         """Returns a fully-qualified occurrence string."""
         return "projects/{project}/occurrences/{occurrence}".format(
-            project=project, occurrence=occurrence,
+            project=project,
+            occurrence=occurrence,
         )
 
     @staticmethod
@@ -188,9 +201,13 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def project_path(project: str,) -> str:
+    def project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_project_path(path: str) -> Dict[str, str]:
@@ -199,7 +216,9 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -212,9 +231,13 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -223,9 +246,13 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -234,9 +261,13 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -245,10 +276,14 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -257,13 +292,17 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
-    def __init__(self, *, transport: Union[str, GrafeasTransport] = None,) -> None:
+    def __init__(
+        self,
+        *,
+        transport: Union[str, GrafeasTransport] = None,
+    ) -> None:
         """Instantiate the grafeas client.
 
         Args:
             transport (Union[str, ~.GrafeasTransport]): The
                 transport to use.
-            
+
 
         Raises:
             google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
@@ -360,7 +399,12 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -460,12 +504,20 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListOccurrencesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -484,7 +536,6 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         this method to delete an occurrence when the occurrence
         is no longer applicable for the given resource.
 
-
         .. code-block:: python
 
             from grafeas import grafeas_v1
@@ -550,7 +601,10 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def create_occurrence(
@@ -646,7 +700,12 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -747,7 +806,12 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -852,7 +916,12 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -870,7 +939,6 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         Consumer projects can use this method to get a note that
         belongs to a provider project.
 
-
         .. code-block:: python
 
             from grafeas import grafeas_v1
@@ -945,7 +1013,12 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1034,7 +1107,12 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1134,12 +1212,20 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListNotesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1221,7 +1307,10 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def create_note(
@@ -1326,7 +1415,12 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1336,7 +1430,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         request: Union[grafeas.BatchCreateNotesRequest, dict] = None,
         *,
         parent: str = None,
-        notes: Sequence[grafeas.BatchCreateNotesRequest.NotesEntry] = None,
+        notes: Mapping[str, grafeas.Note] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -1373,7 +1467,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            notes (Sequence[grafeas.grafeas_v1.types.BatchCreateNotesRequest.NotesEntry]):
+            notes (Mapping[str, grafeas.grafeas_v1.types.Note]):
                 The notes to create. Max allowed
                 length is 1000.
 
@@ -1424,7 +1518,12 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1529,7 +1628,12 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1549,7 +1653,6 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         occurrences across consumer projects referencing the
         specified note.
 
-
         .. code-block:: python
 
             from grafeas import grafeas_v1
@@ -1635,12 +1738,20 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListNoteOccurrencesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1662,7 +1773,9 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("grafeas",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "grafeas",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
