@@ -30,7 +30,9 @@ from grafeas.grafeas_v1.types import grafeas
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("grafeas",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "grafeas",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
@@ -79,6 +81,7 @@ class GrafeasTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -165,7 +168,9 @@ class GrafeasTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_occurrence: gapic_v1.method.wrap_method(
-                self.create_occurrence, default_timeout=30.0, client_info=client_info,
+                self.create_occurrence,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.batch_create_occurrences: gapic_v1.method.wrap_method(
                 self.batch_create_occurrences,
@@ -173,7 +178,9 @@ class GrafeasTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.update_occurrence: gapic_v1.method.wrap_method(
-                self.update_occurrence, default_timeout=30.0, client_info=client_info,
+                self.update_occurrence,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.get_occurrence_note: gapic_v1.method.wrap_method(
                 self.get_occurrence_note,
@@ -236,13 +243,19 @@ class GrafeasTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_note: gapic_v1.method.wrap_method(
-                self.create_note, default_timeout=30.0, client_info=client_info,
+                self.create_note,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.batch_create_notes: gapic_v1.method.wrap_method(
-                self.batch_create_notes, default_timeout=30.0, client_info=client_info,
+                self.batch_create_notes,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.update_note: gapic_v1.method.wrap_method(
-                self.update_note, default_timeout=30.0, client_info=client_info,
+                self.update_note,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.list_note_occurrences: gapic_v1.method.wrap_method(
                 self.list_note_occurrences,
@@ -264,9 +277,9 @@ class GrafeasTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -402,5 +415,9 @@ class GrafeasTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("GrafeasTransport",)
