@@ -240,8 +240,7 @@ class GrafeasGrpcTransport(GrafeasTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -614,5 +613,9 @@ class GrafeasGrpcTransport(GrafeasTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("GrafeasGrpcTransport",)
