@@ -146,13 +146,37 @@ class Occurrence(proto.Message):
             https://github.com/secure-systems-lab/dsse
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    resource_uri = proto.Field(proto.STRING, number=2,)
-    note_name = proto.Field(proto.STRING, number=3,)
-    kind = proto.Field(proto.ENUM, number=4, enum=common.NoteKind,)
-    remediation = proto.Field(proto.STRING, number=5,)
-    create_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    resource_uri = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    note_name = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    kind = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=common.NoteKind,
+    )
+    remediation = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
     vulnerability = proto.Field(
         proto.MESSAGE,
         number=8,
@@ -160,13 +184,22 @@ class Occurrence(proto.Message):
         message=g_vulnerability.VulnerabilityOccurrence,
     )
     build = proto.Field(
-        proto.MESSAGE, number=9, oneof="details", message=g_build.BuildOccurrence,
+        proto.MESSAGE,
+        number=9,
+        oneof="details",
+        message=g_build.BuildOccurrence,
     )
     image = proto.Field(
-        proto.MESSAGE, number=10, oneof="details", message=g_image.ImageOccurrence,
+        proto.MESSAGE,
+        number=10,
+        oneof="details",
+        message=g_image.ImageOccurrence,
     )
     package = proto.Field(
-        proto.MESSAGE, number=11, oneof="details", message=g_package.PackageOccurrence,
+        proto.MESSAGE,
+        number=11,
+        oneof="details",
+        message=g_package.PackageOccurrence,
     )
     deployment = proto.Field(
         proto.MESSAGE,
@@ -187,7 +220,10 @@ class Occurrence(proto.Message):
         message=g_attestation.AttestationOccurrence,
     )
     upgrade = proto.Field(
-        proto.MESSAGE, number=15, oneof="details", message=g_upgrade.UpgradeOccurrence,
+        proto.MESSAGE,
+        number=15,
+        oneof="details",
+        message=g_upgrade.UpgradeOccurrence,
     )
     compliance = proto.Field(
         proto.MESSAGE,
@@ -201,7 +237,11 @@ class Occurrence(proto.Message):
         oneof="details",
         message=g_dsse_attestation.DSSEAttestationOccurrence,
     )
-    envelope = proto.Field(proto.MESSAGE, number=18, message=common.Envelope,)
+    envelope = proto.Field(
+        proto.MESSAGE,
+        number=18,
+        message=common.Envelope,
+    )
 
 
 class Note(proto.Message):
@@ -286,19 +326,47 @@ class Note(proto.Message):
             This field is a member of `oneof`_ ``type``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    short_description = proto.Field(proto.STRING, number=2,)
-    long_description = proto.Field(proto.STRING, number=3,)
-    kind = proto.Field(proto.ENUM, number=4, enum=common.NoteKind,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    short_description = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    long_description = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    kind = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=common.NoteKind,
+    )
     related_url = proto.RepeatedField(
-        proto.MESSAGE, number=5, message=common.RelatedUrl,
+        proto.MESSAGE,
+        number=5,
+        message=common.RelatedUrl,
     )
     expiration_time = proto.Field(
-        proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=timestamp_pb2.Timestamp,
+    )
+    related_note_names = proto.RepeatedField(
+        proto.STRING,
+        number=9,
     )
-    create_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,)
-    related_note_names = proto.RepeatedField(proto.STRING, number=9,)
     vulnerability = proto.Field(
         proto.MESSAGE,
         number=10,
@@ -306,28 +374,52 @@ class Note(proto.Message):
         message=g_vulnerability.VulnerabilityNote,
     )
     build = proto.Field(
-        proto.MESSAGE, number=11, oneof="type", message=g_build.BuildNote,
+        proto.MESSAGE,
+        number=11,
+        oneof="type",
+        message=g_build.BuildNote,
     )
     image = proto.Field(
-        proto.MESSAGE, number=12, oneof="type", message=g_image.ImageNote,
+        proto.MESSAGE,
+        number=12,
+        oneof="type",
+        message=g_image.ImageNote,
     )
     package = proto.Field(
-        proto.MESSAGE, number=13, oneof="type", message=g_package.PackageNote,
+        proto.MESSAGE,
+        number=13,
+        oneof="type",
+        message=g_package.PackageNote,
     )
     deployment = proto.Field(
-        proto.MESSAGE, number=14, oneof="type", message=g_deployment.DeploymentNote,
+        proto.MESSAGE,
+        number=14,
+        oneof="type",
+        message=g_deployment.DeploymentNote,
     )
     discovery = proto.Field(
-        proto.MESSAGE, number=15, oneof="type", message=g_discovery.DiscoveryNote,
+        proto.MESSAGE,
+        number=15,
+        oneof="type",
+        message=g_discovery.DiscoveryNote,
     )
     attestation = proto.Field(
-        proto.MESSAGE, number=16, oneof="type", message=g_attestation.AttestationNote,
+        proto.MESSAGE,
+        number=16,
+        oneof="type",
+        message=g_attestation.AttestationNote,
     )
     upgrade = proto.Field(
-        proto.MESSAGE, number=17, oneof="type", message=g_upgrade.UpgradeNote,
+        proto.MESSAGE,
+        number=17,
+        oneof="type",
+        message=g_upgrade.UpgradeNote,
     )
     compliance = proto.Field(
-        proto.MESSAGE, number=18, oneof="type", message=g_compliance.ComplianceNote,
+        proto.MESSAGE,
+        number=18,
+        oneof="type",
+        message=g_compliance.ComplianceNote,
     )
     dsse_attestation = proto.Field(
         proto.MESSAGE,
@@ -346,7 +438,10 @@ class GetOccurrenceRequest(proto.Message):
             ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListOccurrencesRequest(proto.Message):
@@ -367,10 +462,22 @@ class ListOccurrencesRequest(proto.Message):
             in the list.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListOccurrencesResponse(proto.Message):
@@ -389,8 +496,15 @@ class ListOccurrencesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    occurrences = proto.RepeatedField(proto.MESSAGE, number=1, message="Occurrence",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    occurrences = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Occurrence",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class DeleteOccurrenceRequest(proto.Message):
@@ -402,7 +516,10 @@ class DeleteOccurrenceRequest(proto.Message):
             ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateOccurrenceRequest(proto.Message):
@@ -417,8 +534,15 @@ class CreateOccurrenceRequest(proto.Message):
             The occurrence to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    occurrence = proto.Field(proto.MESSAGE, number=2, message="Occurrence",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    occurrence = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Occurrence",
+    )
 
 
 class UpdateOccurrenceRequest(proto.Message):
@@ -434,10 +558,19 @@ class UpdateOccurrenceRequest(proto.Message):
             The fields to update.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    occurrence = proto.Field(proto.MESSAGE, number=2, message="Occurrence",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    occurrence = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Occurrence",
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=3,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -450,7 +583,10 @@ class GetNoteRequest(proto.Message):
             ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GetOccurrenceNoteRequest(proto.Message):
@@ -463,7 +599,10 @@ class GetOccurrenceNoteRequest(proto.Message):
             ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListNotesRequest(proto.Message):
@@ -484,10 +623,22 @@ class ListNotesRequest(proto.Message):
             in the list.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListNotesResponse(proto.Message):
@@ -506,8 +657,15 @@ class ListNotesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    notes = proto.RepeatedField(proto.MESSAGE, number=1, message="Note",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    notes = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Note",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class DeleteNoteRequest(proto.Message):
@@ -519,7 +677,10 @@ class DeleteNoteRequest(proto.Message):
             ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateNoteRequest(proto.Message):
@@ -536,9 +697,19 @@ class CreateNoteRequest(proto.Message):
             The note to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    note_id = proto.Field(proto.STRING, number=2,)
-    note = proto.Field(proto.MESSAGE, number=3, message="Note",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    note_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    note = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Note",
+    )
 
 
 class UpdateNoteRequest(proto.Message):
@@ -554,10 +725,19 @@ class UpdateNoteRequest(proto.Message):
             The fields to update.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    note = proto.Field(proto.MESSAGE, number=2, message="Note",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    note = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Note",
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=3,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -577,10 +757,22 @@ class ListNoteOccurrencesRequest(proto.Message):
             in the list.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListNoteOccurrencesResponse(proto.Message):
@@ -599,8 +791,15 @@ class ListNoteOccurrencesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    occurrences = proto.RepeatedField(proto.MESSAGE, number=1, message="Occurrence",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    occurrences = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Occurrence",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class BatchCreateNotesRequest(proto.Message):
@@ -611,13 +810,21 @@ class BatchCreateNotesRequest(proto.Message):
             The name of the project in the form of
             ``projects/[PROJECT_ID]``, under which the notes are to be
             created.
-        notes (Sequence[grafeas.grafeas_v1.types.BatchCreateNotesRequest.NotesEntry]):
+        notes (Mapping[str, grafeas.grafeas_v1.types.Note]):
             The notes to create. Max allowed length is
             1000.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    notes = proto.MapField(proto.STRING, proto.MESSAGE, number=2, message="Note",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    notes = proto.MapField(
+        proto.STRING,
+        proto.MESSAGE,
+        number=2,
+        message="Note",
+    )
 
 
 class BatchCreateNotesResponse(proto.Message):
@@ -628,7 +835,11 @@ class BatchCreateNotesResponse(proto.Message):
             The notes that were created.
     """
 
-    notes = proto.RepeatedField(proto.MESSAGE, number=1, message="Note",)
+    notes = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Note",
+    )
 
 
 class BatchCreateOccurrencesRequest(proto.Message):
@@ -644,8 +855,15 @@ class BatchCreateOccurrencesRequest(proto.Message):
             is 1000.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    occurrences = proto.RepeatedField(proto.MESSAGE, number=2, message="Occurrence",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    occurrences = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="Occurrence",
+    )
 
 
 class BatchCreateOccurrencesResponse(proto.Message):
@@ -656,7 +874,11 @@ class BatchCreateOccurrencesResponse(proto.Message):
             The occurrences that were created.
     """
 
-    occurrences = proto.RepeatedField(proto.MESSAGE, number=1, message="Occurrence",)
+    occurrences = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Occurrence",
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
