@@ -20,7 +20,11 @@ from grafeas.grafeas_v1.types import slsa_provenance as g_slsa_provenance
 
 
 __protobuf__ = proto.module(
-    package="grafeas.v1", manifest={"InTotoStatement", "Subject",},
+    package="grafeas.v1",
+    manifest={
+        "InTotoStatement",
+        "Subject",
+    },
 )
 
 
@@ -53,9 +57,19 @@ class InTotoStatement(proto.Message):
             This field is a member of `oneof`_ ``predicate``.
     """
 
-    type_ = proto.Field(proto.STRING, number=1,)
-    subject = proto.RepeatedField(proto.MESSAGE, number=2, message="Subject",)
-    predicate_type = proto.Field(proto.STRING, number=3,)
+    type_ = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    subject = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="Subject",
+    )
+    predicate_type = proto.Field(
+        proto.STRING,
+        number=3,
+    )
     provenance = proto.Field(
         proto.MESSAGE,
         number=4,
@@ -76,14 +90,21 @@ class Subject(proto.Message):
     Attributes:
         name (str):
 
-        digest (Sequence[grafeas.grafeas_v1.types.Subject.DigestEntry]):
+        digest (Mapping[str, str]):
             ``"<ALGORITHM>": "<HEX_VALUE>"`` Algorithms can be e.g.
             sha256, sha512 See
             https://github.com/in-toto/attestation/blob/main/spec/field_types.md#DigestSet
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    digest = proto.MapField(proto.STRING, proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    digest = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
