@@ -64,12 +64,32 @@ class Distribution(proto.Message):
             of this package.
     """
 
-    cpe_uri = proto.Field(proto.STRING, number=1,)
-    architecture = proto.Field(proto.ENUM, number=2, enum="Architecture",)
-    latest_version = proto.Field(proto.MESSAGE, number=3, message="Version",)
-    maintainer = proto.Field(proto.STRING, number=4,)
-    url = proto.Field(proto.STRING, number=5,)
-    description = proto.Field(proto.STRING, number=6,)
+    cpe_uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    architecture = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum="Architecture",
+    )
+    latest_version = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Version",
+    )
+    maintainer = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    url = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class Location(proto.Message):
@@ -89,9 +109,19 @@ class Location(proto.Message):
             package/version is installed.
     """
 
-    cpe_uri = proto.Field(proto.STRING, number=1,)
-    version = proto.Field(proto.MESSAGE, number=2, message="Version",)
-    path = proto.Field(proto.STRING, number=3,)
+    cpe_uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    version = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Version",
+    )
+    path = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class PackageNote(proto.Message):
@@ -107,9 +137,14 @@ class PackageNote(proto.Message):
             distributed.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     distribution = proto.RepeatedField(
-        proto.MESSAGE, number=10, message="Distribution",
+        proto.MESSAGE,
+        number=10,
+        message="Distribution",
     )
 
 
@@ -127,8 +162,15 @@ class PackageOccurrence(proto.Message):
             found.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    location = proto.RepeatedField(proto.MESSAGE, number=2, message="Location",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    location = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="Location",
+    )
 
 
 class Version(proto.Message):
@@ -173,12 +215,31 @@ class Version(proto.Message):
         MINIMUM = 2
         MAXIMUM = 3
 
-    epoch = proto.Field(proto.INT32, number=1,)
-    name = proto.Field(proto.STRING, number=2,)
-    revision = proto.Field(proto.STRING, number=3,)
-    inclusive = proto.Field(proto.BOOL, number=6,)
-    kind = proto.Field(proto.ENUM, number=4, enum=VersionKind,)
-    full_name = proto.Field(proto.STRING, number=5,)
+    epoch = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    revision = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    inclusive = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
+    kind = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=VersionKind,
+    )
+    full_name = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
